using Microsoft.Data.Sqlite;

namespace Tarpit;

public class DatabaseUtils
{
    public readonly string[] ConnectionStrings;
    
    private const string DefaultStatement = "PRAGMA synchronous = OFF; PRAGMA temp_store = MEMORY;" +
                                            " PRAGMA journal_mode = MEMORY; PRAGMA foreign_keys = off;" +
                                            " INSERT INTO Tags (Paragraph)" +
                                            " VALUES (@paragraph)";
    
    public DatabaseUtils(string path)
    {
        string[] wordLists = Directory.GetFiles(path, "*.txt", SearchOption.TopDirectoryOnly);
        
        ConnectionStrings = new string[wordLists.Length];
        
        for (int i = 0; i < wordLists.Length; i++)
        {
            FileInfo fileInfo = new(wordLists[i]);
            ConnectionStrings[i] = $"Data Source={Directory.GetParent(path)}/Database/{fileInfo.Name.Split('.')[0]}.db";
            
            CreateDatabase(ConnectionStrings[i]);
        }
    }
    
    public void InsertTags(string tableName, string tag)
    {
        SqliteConnection connection = new(tableName);
        connection.Open();
        
        using SqliteCommand command = new(DefaultStatement, connection);
        
        command.Parameters.AddWithValue("@paragraph", tag);
        
        _ = command.ExecuteNonQuery();
        
        connection.Close();
    }
    
    private void CreateDatabase(string connectionString)
    {
        string createStatement = $"CREATE TABLE IF NOT EXISTS Tags (Id INTEGER NOT NULL, Paragraph TEXT NOT NULL, PRIMARY KEY(Id AUTOINCREMENT))";
        
        using SqliteConnection connection = new(connectionString);
        connection.Open();
        
        using SqliteCommand command = new(createStatement, connection);
        command.ExecuteNonQuery();
    }
}